@@ -13,6 +13,6 @@
 
 namespace fatal {
 
-CREATE_BENCHMARK(n5_len10, s10_00, s10_01, s10_02, s10_03, s10_04)
+CREATE_BENCHMARK(n2_len5, s5_00, s5_01)
 
 } // namespace fatal {
